@@ -13,14 +13,14 @@ sub BaseTests {
     # Test bare number processing
     diag "tests with bare numbers" if $Verbose;
     $version = $CLASS->new(5.005_03);
-    is ( "$version" , "5.005030" , '5.005_03 eq 5.5.30' );
+    is ( "$version" , "5.00503" , '5.005_03 eq 5.00503' );
     $version = $CLASS->new(1.23);
-    is ( "$version" , "1.230" , '1.23 eq "1.230"' );
+    is ( "$version" , "1.23" , '1.23 eq "1.23"' );
     
     # Test quoted number processing
     diag "tests with quoted numbers" if $Verbose;
     $version = $CLASS->new("5.005_03");
-    is ( "$version" , "5.005_030" , '"5.005_03" eq "5.005_030"' );
+    is ( "$version" , "5.005_03" , '"5.005_03" eq "5.005_03"' );
     $version = $CLASS->new("v1.23");
     is ( "$version" , "v1.23.0" , '"v1.23" eq "v1.23.0"' );
     
@@ -66,7 +66,7 @@ sub BaseTests {
 
     like($warning, qr/$warnregex/,
 	"Version string contains invalid data; ignoring");
-    ok ("$version" eq "99.000", '$version eq "99.000"');
+    is ("$version", "99", '$version eq "99"');
     ok ($version->numify == 99.0, '$version->numify == 99.0');
     ok ($version->normal eq "v99.0.0", '$version->normal eq v99.0.0');
     
@@ -86,33 +86,12 @@ sub BaseTests {
     
     # Test comparison operators with self
     diag "tests with self" if $Verbose;
-    ok ( $version eq $version, '$version eq $version' );
-    is ( $version cmp $version, 0, '$version cmp $version == 0' );
+    is ( $version <=> $version, 0, '$version <=> $version == 0' );
     ok ( $version == $version, '$version == $version' );
     
-    # test first with non-object
-    $version = $CLASS->new("5.006.001");
-    $new_version = "5.8.0";
-    diag "tests with non-objects" if $Verbose;
-    ok ( $version ne $new_version, '$version ne $new_version' );
-    ok ( $version lt $new_version, '$version lt $new_version' );
-    ok ( $new_version gt $version, '$new_version gt $version' );
-    ok ( ref(\$new_version) eq 'SCALAR', 'no auto-upgrade');
-    $new_version = "$version";
-    ok ( $version eq $new_version, '$version eq $new_version' );
-    ok ( $new_version eq $version, '$new_version eq $version' );
-    
-    # now test with existing object
-    $new_version = $CLASS->new("5.8.0");
-    diag "tests with objects" if $Verbose;
-    ok ( $version ne $new_version, '$version ne $new_version' );
-    ok ( $version lt $new_version, '$version lt $new_version' );
-    ok ( $new_version gt $version, '$new_version gt $version' );
-    $new_version = $CLASS->new("$version");
-    ok ( $version eq $new_version, '$version eq $new_version' );
-    
     # Test Numeric Comparison operators
     # test first with non-object
+    $version = $CLASS->new("5.006.001");
     $new_version = "5.8.0";
     diag "numeric tests with non-objects" if $Verbose;
     ok ( $version == $version, '$version == $version' );
@@ -137,20 +116,20 @@ sub BaseTests {
     # test with long decimals
     diag "Tests with extended decimal versions" if $Verbose;
     $version = $CLASS->new(1.002003);
-    ok ( $version eq "1.2.3", '$version eq "1.2.3"');
+    ok ( $version == "1.2.3", '$version == "1.2.3"');
     ok ( $version->numify == 1.002003, '$version->numify == 1.002003');
     $version = $CLASS->new("2002.09.30.1");
-    ok ( $version eq "2002.9.30.1",'$version eq 2002.9.30.1');
+    ok ( $version == "2002.9.30.1",'$version == 2002.9.30.1');
     ok ( $version->numify == 2002.009030001,
 	'$version->numify == 2002.009030001');
     
     # now test with alpha version form with string
     $version = $CLASS->new("1.2.3");
     $new_version = "1.2.3_4";
-    diag "tests with alpha-style non-objects" if $Verbose;
-    ok ( $version lt $new_version, '$version lt $new_version' );
-    ok ( $new_version gt $version, '$new_version gt $version' );
-    ok ( $version ne $new_version, '$version ne $new_version' );
+    diag "numeric tests with alpha-style non-objects" if $Verbose;
+    ok ( $version < $new_version, '$version < $new_version' );
+    ok ( $new_version > $version, '$new_version > $version' );
+    ok ( $version != $new_version, '$version != $new_version' );
     
     $version = $CLASS->new("1.2.4");
     diag "numeric tests with alpha-style non-objects"
@@ -210,9 +189,9 @@ SKIP: {
     # test the qv() sub
     diag "testing qv" if $Verbose;
     $version = qv("1.2");
-    cmp_ok ( $version, "eq", "v1.2.0", 'qv("1.2") eq "1.2.0"' );
+    is ( "$version", "v1.2.0", 'qv("1.2") == "1.2.0"' );
     $version = qv(1.2);
-    cmp_ok ( $version, "eq", "v1.2.0", 'qv(1.2) eq "1.2.0"' );
+    is ( "$version", "v1.2.0", 'qv(1.2) == "1.2.0"' );
     isa_ok( qv('5.008'), $CLASS );
 }
 
@@ -223,21 +202,21 @@ SKIP: {
     ok ($new_version == $version, "class->new($version) identical");
     $new_version = $version->new();
     isa_ok ($new_version, $CLASS );
-    is ($new_version, "0.000", "version->new() doesn't clone");
+    is ($new_version, "0", "version->new() doesn't clone");
     $new_version = $version->new("1.2.3");
     is ($new_version, "v1.2.3" , '$version->new("1.2.3") works too');
 
     # test the CVS revision mode
     diag "testing CVS Revision" if $Verbose;
     $version = new $CLASS qw$Revision: 1.2$;
-    ok ( $version eq "1.2.0", 'qw$Revision: 1.2$ eq 1.2.0' );
+    ok ( $version == "1.2.0", 'qw$Revision: 1.2$ == 1.2.0' );
     $version = new $CLASS qw$Revision: 1.2.3.4$;
-    ok ( $version eq "1.2.3.4", 'qw$Revision: 1.2.3.4$ eq 1.2.3.4' );
+    ok ( $version == "1.2.3.4", 'qw$Revision: 1.2.3.4$ == 1.2.3.4' );
     
     # test the CPAN style reduced significant digit form
     diag "testing CPAN-style versions" if $Verbose;
     $version = $CLASS->new("1.23_01");
-    is ( "$version" , "1.23_0100", "CPAN-style alpha version" );
+    is ( "$version" , "1.23_01", "CPAN-style alpha version" );
     ok ( $version > 1.23, "1.23_01 > 1.23");
     ok ( $version < 1.24, "1.23_01 < 1.24");
 
@@ -260,7 +239,7 @@ SKIP: {
 	
 	# test as class method
 	$new_version = "aaa"->VERSION;
-	cmp_ok($new_version,'eq',$version, "Called as class method");
+	cmp_ok($new_version,'==',$version, "Called as class method");
 
 	eval "print Completely::Unknown::Module->VERSION";
 	if ( $] < 5.008 ) {
@@ -344,15 +323,14 @@ SKIP: 	{
 		if $] < 5.006_000; 
 	diag "Tests with v-strings" if $Verbose;
 	$version = $CLASS->new(1.2.3);
-	ok("$version" eq "v1.2.3", '"$version" eq 1.2.3');
+	ok("$version" == "v1.2.3", '"$version" == 1.2.3');
 	$version = $CLASS->new(1.0.0);
 	$new_version = $CLASS->new(1);
 	ok($version == $new_version, '$version == $new_version');
-	ok($version eq $new_version, '$version eq $new_version');
 	skip "version require'd instead of use'd, cannot test qv", 1
 	    if defined $no_qv;
 	$version = qv(1.2.3);
-	ok("$version" eq "v1.2.3", 'v-string initialized qv()');
+	ok("$version" == "v1.2.3", 'v-string initialized qv()');
     }
 
     diag "Tests with real-world (malformed) data" if $Verbose;
@@ -376,8 +354,8 @@ SKIP: 	{
     ok($version->numify eq "1.700", "leading space ignored");
 
     # RT 19517 - deal with undef and 'undef' initialization
-    ok($version ne 'undef', "Undef version comparison #1");
-    ok($version ne undef, "Undef version comparison #2");
+    ok("$version" ne 'undef', "Undef version comparison #1");
+    ok("$version" ne undef, "Undef version comparison #2");
     $version = $CLASS->new('undef');
     unlike($warning, qr/^Version string 'undef' contains invalid data/,
 	"Version string 'undef'");
@@ -385,12 +363,12 @@ SKIP: 	{
     $version = $CLASS->new(undef);
     like($warning, qr/^Use of uninitialized value/,
 	"Version string 'undef'");
-    ok($version eq 'undef', "Undef version comparison #3");
-    ok($version eq undef, "Undef version comparison #4");
+    ok($version == 'undef', "Undef version comparison #3");
+    ok($version ==  undef,  "Undef version comparison #4");
     eval "\$version = \$CLASS->new()"; # no parameter at all
     unlike($@, qr/^Bizarre copy of CODE/, "No initializer at all");
-    ok($version eq 'undef', "Undef version comparison #5");
-    ok($version eq undef, "Undef version comparison #6");
+    ok($version == 'undef', "Undef version comparison #5");
+    ok($version ==  undef,  "Undef version comparison #6");
 
     $version = $CLASS->new(0.000001);
     unlike($warning, qr/^Version string '1e-06' contains invalid data/,
@@ -487,7 +465,7 @@ SKIP: {
 	my $v = $CLASS->new($ver);
 	unlike($warning,qr/Version string '1,23' contains invalid data/,
 	    "Process locale-dependent floating point");
-	is ($v, "1.230", "Locale doesn't apply to version objects");
+	is ($v, "1.23", "Locale doesn't apply to version objects");
 	ok ($v == $ver, "Comparison to locale floating point");
     }
 
